% Diamond Model in discrete time
% _____________________________________
%
% Two permanent shocks are introduced in order to study 
% the dynamic behavior of the model
%
% 1. A 1 per cent shock to the pure rate of time preference (endval x 1.01) 
% 2. A 1 per cent shock to total factor productivity (endval a 1.01)
% 
% _____________________________________
%
% Endogenous Variables: 
% y output, k capital, c consumption
% w real wage, r real interest rate, s savings rate
%
% Exogenous Variables and Shocks
% a total factor productivity, x shock to the pure rate of time preference
% z shock to population growth
%
% Parameters
% alpha share of capital in production, delta depreciation rate
% n population growth rate, g rate of technical progress
% rho pure rate of time preference
% theta inverse of elasticity of intertemporal substitution
%
% ______________________________________

var y k c w r s z;
varexo a x p;

parameters alpha delta n g rho theta;

alpha=0.333;
delta=1.427;
n=0.348;
g=0.811;
rho=0.811;
theta=1.0;

model;

k=(1/((1+n*p)*(1+g)*(1+2*rho*x)))*(1-alpha)*a*(k(-1))^alpha;
y=a*(k(-1)^alpha);
r=(alpha*a*k^(alpha-1))-delta;
w=(1-alpha)*a*k(-1)^(alpha);
s=((1+r)^((1-theta)/theta))/(((1+(rho*x))^(1/theta))+((1+r)^((1-theta)/theta)));
c=(1-s)*w+(1+r(-1)+delta)*k(-1);
z=(y-c)/y;

end;

initval;

k=0.14;
c=0.43;
y=0.55;
a=1;
r=1.30;
w=0.36;
s=0.31;
x=1;
p=1;
z=0.21;

end;

steady;

endval;

k=0.14;
c=0.43;
y=0.55;
a=1.01;
r=1.30;
w=0.36;
s=0.31;
x=1.0;
p=1.0;
z=0.21;

end;

steady;
check;

simul(periods=100);

% Plotting Capital Output Consumption Real Interest Rate Real Wage Savings
% Rate
subplot(3,2,1); plot(k(1:25,1)); title('Capital');
subplot(3,2,2); plot(y(1:25,1)); title('Output');
subplot(3,2,3); plot(c(1:25,1)); title('Consumption');
subplot(3,2,4); plot(w(1:25,1)); title('Real Wage');
subplot(3,2,5); plot(r(1:25,1)); title('Real Interest Rate');
subplot(3,2,6); plot(z(1:25,1)); title('Savings Rate');

